# Contributors

[anndata graph](https://github.com/scverse/anndata/graphs/contributors>) | [scanpy graph](https://github.com/scverse/scanpy/graphs/contributors)| ☀ = maintainer

## Current developers

- [Philipp Angerer](https://github.com/flying-sheep), lead developer since 2023, software quality, initial anndata conception ☀
- [Ilan Gold](https://github.com/ilan-gold), developer, Dask ☀
- [Severin Dicks](https://github.com/SeverinDicks), developer, performance ☀
- [Lukas Heumos](https://twitter.com/LukasHeumos), developer, diverse contributions

## Other roles

- [Isaac Virshup](https://github.com/ivirshup), lead developer 2019-2023
- [Alex Wolf](https://twitter.com/falexwolf): lead developer 2016-2019, initial anndata & scanpy conception
- [Fabian Theis](https://twitter.com/fabian_theis) & lab: enabling guidance, support and environment

## Former developers

- [Tom White](https://github.com/tomwhite): developer 2018-2019, distributed computing
- [Gökcen Eraslan](https://twitter.com/gokcen), developer, diverse contributions
- [Sergei Rybakov](https://github.com/Koncopd), developer, diverse contributions
- [Fidel Ramirez](https://github.com/fidelram) developer, plotting
- [Giovanni Palla](https://twitter.com/g_palla1), developer, spatial data
- [Malte Luecken](https://twitter.com/MDLuecken), developer, community & forum
